#!/bin/bash

#
# Copyright (c) 2010 Ingres Corp.
#

TOPDIR="`cat .topdir`"
IVWDIR="$TOPDIR/scripts/ingres_vectorwise"

usage()
{
cat << EOF
usage: $0 options

The script runs TPC-H ACID Atomicity Test #1

OPTIONS:
    -h              show this message
    -d  <database>  database name
EOF
}

DATABASE=
while getopts "d:" opt; do
    case $opt in
        d)
            DATABASE=$OPTARG
            ;;
        ?)
            usage
            exit 1
            ;;
    esac
done

if [ -z "$DATABASE" ]; then
	usage
	exit 1
fi

echo "======================="
echo "TPC-H Atomicity Test #1"
echo "======================="
echo "Test Started at: `date`"
echo

# truncate HISTORY table
echo "Truncate the HISTORY table:"
echo "delete from HISTORY;\p\g" | sql $DATABASE

# generate and show random values used
RAND_VALUES=`$IVWDIR/acid/acidkeys -b $DATABASE -c 1`
RAND_O_KEY=`echo $RAND_VALUES | awk '{printf $1}'`
RAND_L_KEY=`echo $RAND_VALUES | awk '{printf $2}'`
RAND_DELTA=`echo $RAND_VALUES | awk '{printf $3}'`

echo "Random values used:"
echo "O_KEY = $RAND_O_KEY"
echo "L_KEY = $RAND_L_KEY"
echo "DELTA = $RAND_DELTA"

# run TPC-H transaction
echo $RAND_VALUES | $IVWDIR/acid/acidtrans -b $DATABASE

# show HISTORY table
echo
echo "Contents of the HISTORY table:"
echo "select * from history;\p\g" | sql $DATABASE

echo
echo "Teste Ended at: `date`"

