/*
 * Copyright (c) 2010 Ingres Corp.
 */

#include <time.h>
#include <stdio.h>
#include <stdlib.h>
#include <signal.h>
#include <string.h>
#include <sys/types.h>
#include <unistd.h>
#include <sys/stat.h>
#include <fcntl.h>

EXEC SQL INCLUDE SQLCA;

static void usage(char *msg)
{
	if (msg)
            fprintf(stderr, "%s\n", msg);
	fprintf( stderr, "usage: consist_condition -b <database> -o <orderkey>\n");
	exit(0);
}

int main( int argc, char **argv)
{
	EXEC SQL BEGIN DECLARE SECTION;
		char *database=NULL;
        double o_totprice;
        double l_totprice;
        long long rand_o_key = -1;
	EXEC SQL END DECLARE SECTION;

	double diff;
	char c;

	while ((c = getopt(argc, argv, ":b:o:")) != -1)
		switch (c) {
		case 'b':
			database = optarg;
			break;
		case 'o':
			rand_o_key = atol(optarg);
			break;
		case ':':  /* -b or -o without arguments */
			usage("option requires an argument");
			break;
		case '?':
			usage("unknown option");
	}

	if (database == NULL)
		usage("no database specified");

	if (rand_o_key == -1)
		usage("no O_KEY specified");

	EXEC SQL WHENEVER SQLERROR STOP;
	EXEC SQL CONNECT TO :database;

	// get TOTALPRICE from ORDERS
	EXEC SQL SELECT O_TOTALPRICE
	INTO :o_totprice
	FROM ORDERS WHERE O_ORDERKEY = :rand_o_key;

	// get TOTALPRICE from LINEITEM
	EXEC SQL SELECT SUM( TRUNC( (TRUNC( (l_extendedprice * (1.0-l_discount)), 2) * (1.0+l_tax)), 2))
	INTO :l_totprice
	FROM LINEITEM WHERE L_ORDERKEY = :rand_o_key;

	// calculate difference
	diff = o_totprice - l_totprice;

	printf("O_ORDERKEY=%lld\tO_TOTALPRICE = %f\tL_TOTALPRICE = %f\tDifference   = %f\n",
			rand_o_key, o_totprice, l_totprice, diff);

	return(0);
}
