#!/bin/bash

#
# Copyright (c) 2010 Ingres Corp.
#

TOPDIR="`cat .topdir`"        
IVWDIR="$TOPDIR/scripts/ingres_vectorwise"

usage()
{
cat << EOF
usage: $0 -d <db> [-s <n>] [-t <n>] [-f <sf>] { -a | -c | -i }

The script runs TPC-H Atomicity, Consistency and Isolation Tests
You must specify one or more of -a -c -i

OPTIONS:
    -h              show this message
    -d  <database>  database name
    -s  <number>    number of streams (default=2) consitiency only
    -t  <number>    number of transactions (default=100) consistency only
    -f  <scale factor> isolation only
    -a              run atomicity
    -c              run consistency
    -i              run isolation
EOF
}

er()
{
	echo "ERROR: $1"
	exit 1
}

DATABASE=
STREAMS=2
NTRAN=100
ATOM=0
CON=0
ISO=0
SF=0
while getopts "d:s:t:f:aci" opt; do
    case $opt in
        d)
            DATABASE=$OPTARG
            ;;
        s)
        	STREAMS=$OPTARG
        	;;
        t)
        	NTRAN=$OPTARG
        	;;
	f)
		SF=$OPTARG
		;;
        a)
		ATOM=1
		;;
	c)
		CON=1
		;;
	i)
		ISO=1
		;;
        ?)
            usage
            exit 1
            ;;
    esac
done

if [ -z "$DATABASE" ]; then
	usage
	exit 1
fi

if [ $((ATOM+CON+ISO)) -eq 0 ]; then
	echo "Error: One or more of -a -c -i must be specified"
	exit 1
fi


# Create HISTORY table
cat $IVWDIR/acid/create_history.sql | sql $DATABASE

# Atomicity
if [ $ATOM -eq 1 ]; then
	echo "======================="
	echo "TPC-H Atomicity Tests"
	echo "======================="
	cd $IVWDIR/acid/atom
	rm -rf output && mkdir -p output
	./atom1.sh -d $DATABASE | tee output/atom1_output || er "Atomicity #1"
	sleep 1
	./atom2.sh -d $DATABASE | tee output/atom2_output || er "Atomicity #2"
	sleep 1
	cd ..
fi

# Consistency
if [ $CON -eq 1 ]; then
	echo "======================="
	echo "TPC-H Consistency Tests"
	echo "======================="

	if [ $STREAMS -lt 2 ]; then
		echo "Error: Number of streams must be >= 2"
		exit 1
	fi
	if [ $NTRAN -lt 100 ]; then
		echo "Error: Number of transactions must be >= 100"
		exit 1
	fi

	cd $IVWDIR/acid/cons
	rm -rf output && mkdir -p output
	./consist.sh -d $DATABASE -s $STREAMS -t $NTRAN | tee output/consist_output || er "Consistency"
	sleep 1
	cd ..
fi

# Isolation
if [ $ISO -eq 1 ]; then
	echo "======================="
	echo "TPC-H Isolation Tests"
	echo "======================="
	if [ $SF -eq 0 ]; then
		echo "Error: Scale factor must be specified for isolation"
		exit 1
	fi
	cd $IVWDIR/acid/iso
	rm -rf output && mkdir -p output
	./iso1.sh -d $DATABASE | tee output/iso1_output || er "Isolation #1"
	sleep 1
	./iso2.sh -d $DATABASE | tee output/iso2_output || er "Isolation #2"
	sleep 1
	./iso3.sh -d $DATABASE | tee output/iso3_output || er "Isolation #3"
	sleep 1
	./iso3b.sh -d $DATABASE | tee output/iso3b_output || er "Isolation #3b"
	sleep 1
	./iso4.sh -d $DATABASE | tee output/iso4_output || er "Isolation #4"
	sleep 1
	./iso4b.sh -d $DATABASE | tee output/iso4b_output || er "Isolation #4b"
	sleep 1
	./iso5.sh -d $DATABASE -f $SF | tee output/iso5_output || er "Isolation #5"
	sleep 1
	./iso6.sh -d $DATABASE | tee output/iso6_output || er "Isolation #6"
	cd ..
fi

echo
echo "========================"
echo "TPC-H ACI Tests finished"
echo "========================"
echo "check the contents of the output dir in atom/, cons/ and iso/."
echo
