CREATE TABLE region (
r_regionkey BIGINT NOT NULL PRIMARY KEY,
r_name CHAR(25) NOT NULL,
r_comment VARCHAR(152) NOT NULL
);
\p\g

CREATE TABLE nation (
n_nationkey BIGINT NOT NULL PRIMARY KEY,
n_name CHAR(25) NOT NULL,
n_regionkey BIGINT NOT NULL REFERENCES region,
n_comment VARCHAR(152) NOT NULL
);
\p\g

CREATE TABLE supplier (
s_suppkey BIGINT NOT NULL PRIMARY KEY,
s_name CHAR(25) NOT NULL,
s_address VARCHAR(40) NOT NULL,
s_nationkey BIGINT NOT NULL REFERENCES nation,
s_phone CHAR(15) NOT NULL,
s_acctbal DECIMAL(12,2) NOT NULL,
s_comment VARCHAR(101) NOT NULL
);
\p\g

CREATE TABLE customer (
c_custkey BIGINT NOT NULL PRIMARY KEY,
c_name VARCHAR(25) NOT NULL,
c_address VARCHAR(40) NOT NULL,
c_nationkey BIGINT NOT NULL REFERENCES nation,
c_phone CHAR(15) NOT NULL,
c_acctbal DECIMAL(12,2) NOT NULL,
c_mktsegment CHAR(10) NOT NULL,
c_comment VARCHAR(117) NOT NULL
);
\p\g

CREATE TABLE part (
p_partkey BIGINT NOT NULL PRIMARY KEY,
p_name VARCHAR(55) NOT NULL,
p_mfgr CHAR(25) NOT NULL,
p_brand CHAR(10) NOT NULL,
p_type VARCHAR(25) NOT NULL,
p_size INTEGER NOT NULL,
p_container CHAR(10) NOT NULL,
p_retailprice DECIMAL(12,2) NOT NULL,
p_comment VARCHAR(23) NOT NULL
);
\p\g

CREATE TABLE partsupp (
ps_partkey BIGINT NOT NULL REFERENCES part,
ps_suppkey BIGINT NOT NULL REFERENCES supplier,
ps_availqty INTEGER NOT NULL,
ps_supplycost DECIMAL(12,2) NOT NULL,
ps_comment VARCHAR(199) NOT NULL,
PRIMARY KEY (ps_partkey, ps_suppkey)
);
\p\g

CREATE TABLE orders (
o_orderkey BIGINT NOT NULL PRIMARY KEY,
o_custkey BIGINT NOT NULL REFERENCES customer,
o_orderstatus CHAR(1) NOT NULL,
o_totalprice DECIMAL(12,2) NOT NULL,
o_orderdate ANSIDATE NOT NULL,
o_orderpriority CHAR(15) NOT NULL,
o_clerk CHAR(15) NOT NULL,
o_shippriority INTEGER NOT NULL,
o_comment VARCHAR(79) NOT NULL
);
\p\g

CREATE TABLE lineitem (
l_orderkey BIGINT NOT NULL REFERENCES orders,
l_partkey BIGINT NOT NULL REFERENCES part,
l_suppkey BIGINT NOT NULL REFERENCES supplier,
l_linenumber INTEGER NOT NULL,
l_quantity DECIMAL(12,2) NOT NULL,
l_extendedprice DECIMAL(12,2) NOT NULL,
l_discount DECIMAL(12,2) NOT NULL,
l_tax DECIMAL(12,2) NOT NULL,
l_returnflag CHAR(1) NOT NULL,
l_linestatus CHAR(1) NOT NULL,
l_shipdate ANSIDATE NOT NULL,
l_commitdate ANSIDATE NOT NULL,
l_receiptdate ANSIDATE NOT NULL,
l_shipinstruct CHAR(25) NOT NULL,
l_shipmode CHAR(10) NOT NULL,
l_comment VARCHAR(44) NOT NULL,
FOREIGN KEY (l_partkey, l_suppkey) REFERENCES partsupp
);
\p\g

