#!/bin/bash

#
# Copyright (c) 2010 Ingres Corp.
#

TOPDIR="`cat .topdir`"       
source $TOPDIR/scripts/kit_profile || er "$0: could not source kit_profile"

unset ERROR
unset DATABASE

while [ $# -ne 0 ]
do
    case $1 in
    -d)     shift;
            DATABASE=$1
        ;;
    *)      echo "Usage: $0"
            echo "     -d  <database> (required)"
            exit 1
            ;;
    esac
    shift
done

if [ -z ${DATABASE} ]; then
	er "database name is required."
fi
	
# Tables
for PREFIX in tmp_lineitem tmp_orderkey tmp_orders; do	
 	TABLES=`echo "select table_name from iitables where table_name like '${PREFIX}%';\g" | sql ${DATABASE} | grep "${PREFIX}" | sed 's/[^a-z0-9_]//g'` 	
	for TABLE in $TABLES; do		
		echo "drop table $TABLE\p\g" | sql ${DATABASE} 1>/dev/null
		if [ "$?" != 0 ]; then
			ERROR="** FAILED to drop table $TABLE"
			echo "$ERROR"
		else
			echo "Table $TABLE dropped successfully"
		fi
	done
done

# Views
for PREFIX in revenue; do
 	VIEWS=`echo "select table_name from iiviews where table_name like '${PREFIX}%';\g" | sql ${DATABASE} | grep "${PREFIX}" | sed 's/[^a-z0-9_]//g'`
	for VIEW in $VIEWS; do
		echo "drop view $VIEW\p\g" | sql ${DATABASE} 1>/dev/null
		if [ "$?" != 0 ]; then
			ERROR="** FAILED to drop view $VIEW"
			echo "$ERROR"
		else
			echo "View $VIEW dropped successfully"
		fi
	done
done

if [ -n "$ERROR" ]; then
	exit 1
fi
