#!/bin/bash

# 
# This file is released under the terms of the Artistic License.
# Please see the file LICENSE, included in this package, for details.
#
# Copyright (c) 2010 Ingres Corp.
#

drop_temp()
{
# drop temp tables and views
cmd="\continue; drop view lineitem_tmp;\p\g"
echo "`cat $header` ${cmd}" | sql $DATABASE >> $OUTPUT_FILE \
           || er "Error on $cmd. See $OUTPUT_FILE"
for ((p=1; p<=$PAR; p++));do
	cmd="\continue; drop table lineitem_tmp_$p;\p\g"
	echo "`cat $header` ${cmd}" | sql $DATABASE >> $OUTPUT_FILE \
           	|| er "Error on $cmd. See $OUTPUT_FILE"
done
cmd="\continue; drop view orders_tmp;\p\g"
echo "`cat $header` ${cmd}" | sql $DATABASE >> $OUTPUT_FILE \
           || er "Error on $cmd. See $OUTPUT_FILE"
for ((p=1; p<=$PAR; p++));do
	cmd="\continue; drop table orders_tmp_$p;\p\g"
	echo "`cat $header` ${cmd}" | sql $DATABASE >> $OUTPUT_FILE \
           	|| er "Error on $cmd. See $OUTPUT_FILE"
done
}

TOPDIR="`cat .topdir`"
IVWDIR="$TOPDIR/scripts/ingres_vectorwise"
source $TOPDIR/scripts/kit_profile || er "$0: could not source kit_profile"

unset SET_NUM
unset DATABASE
unset OUTPUT_DIR
unset DSS_PATH
unset PAR

while [ $# -ne 0 ]
do
    case $1 in
    -d)     shift;
            DATABASE=$1
        ;;
    -df)    shift;
            DSS_PATH=$1
        ;;
    -o)     shift;
            OUTPUT_DIR=$1
        ;;
    -s)     shift;
            SET_NUM=$1
        ;;
    -par)   shift;
	    PAR=$1
	;;
    *)      echo "Usage: $0"
            echo "     -d  <database> (required)"
            echo "     -df <data set directory> (required)" 
            echo "     -o  <output directory> (required)"
            echo "     -s  <data set number> (required)"
            echo "     -par <number> parallelism for refresh data load (required)"
            exit 1
            ;;
    esac
    shift
done

if [ -z ${DATABASE} ]; then
	er "database name is required."
fi
	
if [ -z ${DSS_PATH} ]; then
	er "updata data sets directory is required."
fi

if [ -z ${OUTPUT_DIR} ]; then
        er "output directory is required."
fi

if [ -z ${SET_NUM} ]; then
	er "data set number is required."
fi

if [ -z "$PAR" ]; then
	er "parallelism for refresh load, matching the refresh data dir is required"
fi

RFOUTPUT_DIR="$OUTPUT_DIR/results/rf1"
OUTPUT_FILE="$RFOUTPUT_DIR/setnum${SET_NUM}_output"
mkdir -p $RFOUTPUT_DIR
header="$IVWDIR/import/header"


#
# RF1
#

s_time=`$GTIME`
human_time=`echo $s_time | $IVWDIR/unix2human.awk`
echo "RF1 (set #${SET_NUM}) - Start Time: $human_time" | tee -a $OUTPUT_FILE

# drop temp tables
drop_temp

tmp=`mktemp`
# create and load piece tables 
for ((p=1; p<=$PAR; p++));do
	# Load temp table orders
	echo "s/ordersNN/orders_tmp_$p/" > ${tmp}$p
	sed <$IVWDIR/ddl_p/orders.sql -f ${tmp}$p | sql $DATABASE >>$OUTPUT_FILE \
		|| er "could not create table orders_tmp_$p.  See $OUTPUT_FILE"

	pushd ${DSS_PATH} > /dev/null
	cp $header ${tmp}${p}.sql
	# change the table name
	sed <$IVWDIR/import_p/orders.sql -f ${tmp}$p >> ${tmp}${p}.sql
	# chnage the remainiing NN which is on the copy from file
	echo "s/NN/u${SET_NUM}.$p/" > ${tmp}$p
	sed <${tmp}${p}.sql -f ${tmp}$p  | sql $DATABASE >>$OUTPUT_FILE \
		|| er "could not copy into table orders_tmp_$p.  See $OUTPUT_FILE" &
	popd >/dev/null
done
wait

# create a view of the pieces
cp $header ${tmp}.sql
echo -n "create view orders_tmp as select * from orders_tmp_1 " >${tmp}.sql
for ((p=2; p<=$PAR; p++));do
	echo -n " union all select * from orders_tmp_$p " >>${tmp}.sql
done
echo '\p\g' >>${tmp}.sql
sql <${tmp}.sql $DATABASE >>$OUTPUT_FILE \
	|| er "could not create view orders_tmp . See $OUTPUT_FILE" 


# same for lineitem
# create and load piece tables
for ((p=1; p<=$PAR; p++));do
	echo "s/lineitemNN/lineitem_tmp_$p/" > ${tmp}$p
	sed <$IVWDIR/ddl_p/lineitem.sql -f ${tmp}$p | sql $DATABASE >>$OUTPUT_FILE \
		|| er "could not create table lineitem_tmp_$p.  See $OUTPUT_FILE"

	pushd ${DSS_PATH} > /dev/null
	cp $header ${tmp}${p}.sql
	# change the table name
	sed <$IVWDIR/import_p/lineitem.sql -f ${tmp}$p >> ${tmp}${p}.sql
	# chnage the remainiing NN which is on the copy from file
	echo "s/NN/u${SET_NUM}.$p/" > ${tmp}$p
	sed <${tmp}${p}.sql -f ${tmp}$p  | sql $DATABASE >>$OUTPUT_FILE \
		|| er "could not copy into table lineitem_tmp_$p.  See $OUTPUT_FILE" &
	popd >/dev/null
done
wait

# create view from table pieces
cp $header ${tmp}.sql
echo -n "create view lineitem_tmp as select * from lineitem_tmp_1 " >${tmp}.sql
for ((p=2; p<=$PAR; p++));do
	echo -n " union all select * from lineitem_tmp_$p " >>${tmp}.sql
done
echo '\p\g' >>${tmp}.sql
sql <${tmp}.sql $DATABASE >>$OUTPUT_FILE \
	|| er "could not create view lineitem_tmp . See $OUTPUT_FILE" 


# Run RF1 txn
echo "** Start of RF1 transaction" >> $OUTPUT_FILE
HEADER=`cat $IVWDIR/rf/header`
RF1=`cat $IVWDIR/rf/rf1.sql`;
echo "$HEADER $RF1 commit;\nocontinue\p\g" | sql $DATABASE >> $OUTPUT_FILE \
	|| er "RF1 txn failed. could not insert into orders/lineitem. See $OUTPUT_FILE"
echo "** End of RF1 transaction" >> $OUTPUT_FILE

# drop temp tables
drop_temp


# End RF1
e_time=`$GTIME`
human_time=`echo $e_time | $IVWDIR/unix2human.awk`
echo "RF1 (set #${SET_NUM}) - End Time: $human_time" | tee  -a $OUTPUT_FILE

diff_time=`echo "$s_time $e_time" | awk '{printf("%.2f", $2 - $1);}'`

# Round duration of less than 0.05 to 0.1, then round it to the nearest tenth.
diff_time=`echo $diff_time | awk '{if ($1<0.05) $1=0.1; x=sprintf("%.1f", int($1*10+0.5)/10); printf(x)}'`

echo "RF1 (set #${SET_NUM}) - Duration: $diff_time seconds" | tee  -a $OUTPUT_FILE

echo "RF1 $s_time $e_time" > $RFOUTPUT_DIR/times${SET_NUM}
echo "RF1 (set #${SET_NUM}) - output ==> $OUTPUT_FILE"

